@@ -16,6 +16,7 @@ $this->provideCssFile('vendor/L.Control.Locate.css');
 $this->provideCssFile('vendor/easy-button.css');
 $this->provideCssFile('vendor/leaflet.awesome-markers.css');
 $this->provideCssFile('vendor/leaflet.modal.css');
+$this->provideCssFile('vendor/L.Control.OpenCageData.Search.min.css');
 
 // javascript libraries
 $this->provideJsFile('vendor/spin.js');
@@ -26,6 +27,7 @@ $this->provideJsFile('vendor/L.Control.Locate.js');
 $this->provideJsFile('vendor/easy-button.js');
 $this->provideJsFile('vendor/leaflet.awesome-markers.js');
 $this->provideJsFile('vendor/Leaflet.Modal.js');
+$this->provideJsFile('vendor/L.Control.OpenCageSearch.js');
 
 // configuration menu
 $this->provideConfigTab('config', array(
@@ -33,3 +35,13 @@ $this->provideConfigTab('config', array(
     'label' => $this->translate('Configuration'),
     'url' => 'config'
 ));
+
+if ($this->app->getModuleManager()->hasEnabled("mapDatatype") && $this->app->getModuleManager()->hasEnabled("director")) {
+
+    $this->provideConfigTab('director', array(
+        'title' => $this->translate('Configure the director map datatype'),
+        'label' => $this->translate('Director'),
+        'url' => 'config/director'
+    ));
+
+}
