@@ -69,13 +69,22 @@
             // Protect Icinga filter syntax
             if (isFilterParameter(sURLVariables[i])) {
                 params.push(sURLVariables[i]);
-                continue;
+
             }
         }
 
         return params.join("&")
     }
 
+    function showHost(hostname) {
+        if (cache[id].hostMarkers[hostname]) {
+            var el = cache[id].hostMarkers[hostname];
+            cache[id].markers.zoomToShowLayer(el, function () {
+                el.openPopup();
+            })
+        }
+    }
+
     function showDefaultView() {
         if (map_default_lat !== null && map_default_long !== null) {
             if (map_default_zoom !== null) {
@@ -217,7 +226,7 @@
         this.module = module;
         this.initialize();
         this.timer;
-        this.module.icinga.logger.debug('Map module loaded');
+        // this.module.icinga.logger.debug('Map module loaded');
     };
 
     Map.prototype = {
@@ -232,7 +241,7 @@
             this.timer = this.module.icinga.timer.register(
                 this.updateAllMapData,
                 this,
-                10000
+                60000
             );
             return this;
         },
@@ -253,7 +262,7 @@
             var _this = this;
 
             if (cache.length == 0) {
-                this.removeTimer(id)
+                this.removeTimer(id);
                 return this
             }
 
@@ -271,15 +280,6 @@
             var show_host = parameters.show_host;
             var $that = this;
 
-            function showHost(hostname) {
-                if (cache[id].hostMarkers[hostname]) {
-                    var el = cache[id].hostMarkers[hostname];
-                    cache[id].markers.zoomToShowLayer(el, function () {
-                        el.openPopup();
-                    })
-                }
-            }
-
             function removeOldMarkers(id, data) {
                 // remove old markers
                 $.each(cache[id].hostMarkers, function (identifier, d) {
@@ -314,7 +314,7 @@
                 $.each(json, function (type, element) {
                     $.each(element, function (identifier, data) {
                         if (data.length < 1 || data['coordinates'] == "") {
-                            console.log('found empty coordinates: ' + data)
+                            console.log('found empty coordinates: ' + data);
                             return true
                         }
 
@@ -328,10 +328,16 @@
                             states.push((data['host_state'] == 1 ? 2 : data['host_state']))
                         }
 
+                        var table = '<table class="icinga-module module-monitoring">';
+                        if (isUsingIcingadb) {
+                            //TODO add icingadb design
+                            table = '<table class="icinga-module module-icingadb">';
+                        }
+
                         services = '<div class="map-popup-services">';
                         services += '<h1><span class="icon-services"></span> Services</h1>';
                         services += '<div class="scroll-view">';
-                        services += '<table class="icinga-module module-monitoring">';
+                        services += table;
                         services += '<tbody>';
 
                         $.each(data['services'], function (service_display_name, service) {
@@ -342,30 +348,33 @@
                                 service_handled = " handled";
                             }
 
+                            var ServiceStateClass = " state-" + service_status[service['service_state']][1].toLowerCase();
+                            var ServiceLink = '/monitoring/service/show?host=' + data['host_name'] + '&service=' + service['service_name'];
+                            var tdClasses = "state-col" + ServiceStateClass + service_handled;
+                            var statelabel = '<div class="state-label">' + service_status[service['service_state']][0] + '</div>';
+                            if (isUsingIcingadb) {
+                                ServiceLink = '/icingadb/service?host.name=' + data['host_name'] + '&name=' + service['service_name'];
+                                tdClasses = "state-ball center" + ServiceStateClass + " ball-size-l" + service_handled;
+                                statelabel = "";
+                                if (service_handled) {
+                                    statelabel = '<i class="icon fa fa-check"></i>';
+                                }
+                            }
                             services += '<tr>';
 
-                            services += '<td class="';
-                            services += "state-col";
-                            services += " state-" + service_status[service['service_state']][1].toLowerCase();
-                            services += "" + service_handled;
-                            services += '">';
-                            services += '<div class="state-label">';
-                            services += service_status[service['service_state']][0];
-                            services += '</div>';
+                            services += '<td class="' + tdClasses + '">';
+                            services += statelabel;
                             services += '</td>';
 
                             services += '<td>';
                             services += '<div class="state-header">';
                             services += '<a data-hostname="' + data['host_name'] + '" data-base-target="_next" href="'
                                 + icinga.config.baseUrl
-                                + '/monitoring/service/show?host='
-                                + data['host_name']
-                                + '&service='
-                                + service['service_name']
+                                + ServiceLink
                                 + '">';
                             services += service_display_name;
-                            services += '</a>'
-                            services += '</div>'
+                            services += '</a>';
+                            services += '</div>';
                             services += '</td>';
 
                             services += '</tr>';
@@ -400,12 +409,16 @@
 
                         var host_status = type === 'hosts' && data['host_state'] == 1 ? "<div id=\"hoststatus\">" + translation['host-down'] + "</div>" : "";
 
+                        var hostLink = '/monitoring/host/show?host=' + data['host_name'];
+                        if (isUsingIcingadb) {
+                            hostLink = '/icingadb/host?name=' + data['host_name'];
+                        }
+
                         var info = '<div class="map-popup">';
                         info += '<h1>';
                         info += '<a class="detail-link" data-hostname="' + data['host_name'] + '" data-base-target="_next" href="'
                             + icinga.config.baseUrl
-                            + '/monitoring/host/show?host='
-                            + data['host_name']
+                            + hostLink
                             + '">';
                         info += ' <span class="icon-eye"></span> ';
                         info += '</a>';
@@ -436,6 +449,15 @@
                         }
 
                         marker.bindPopup(info);
+
+                        if (popup_mouseover) {
+                            marker.on('mouseover', function (e) {
+                                this.openPopup();
+                            });
+                            marker.on('mouseout', function (e) {
+                                // this.closePopup();
+                            }); 
+                        }
                     })
                 });
 
@@ -480,24 +502,61 @@
             });
             osm.addTo(cache[id].map);
 
+            var options = {
+                limit: 10,
+                filter: function () {
+                    return filterParams(id, cache[id].parameters);
+                }
+            };
+            var control = L.Control.openCageSearch(options).addTo(cache[id].map);
+
+            control.setMarker(function (el) {
+                if (el['id'] && cache[id].hostMarkers[el.id]) {
+                    showHost(el.id)
+                } else {
+                    var geocodeMarker = new L.Marker(el.center, {
+                        icon: L.AwesomeMarkers.icon({
+                            icon: 'globe',
+                            markerColor: 'blue',
+                            className: 'awesome-marker'
+                        })
+                    })
+                        .bindPopup(el.name)
+                        .addTo(cache[id].map)
+                        .openPopup();
+
+                    cache[id].map.setView(geocodeMarker.getLatLng(), map_max_zoom);
+
+                    geocodeMarker.on('popupclose', function (evt) {
+                        cache[id].map.removeLayer(evt.target);
+                    });
+                }
+            });
+
             cache[id].markers = new L.MarkerClusterGroup({
                 iconCreateFunction: function (cluster) {
-                    var childCount = cluster_problem_count ? 0 : cluster.getChildCount();
+                    var childCount = cluster.getChildCount();
+                    var childProblem = 0;
 
                     var states = [];
                     $.each(cluster.getAllChildMarkers(), function (id, el) {
                         states.push(el.options.state);
                         
-                        if (cluster_problem_count && el.options.state > 0) {
-                            childCount++;
+                        if (el.options.state > 0) {
+                            childProblem++;
                         }
                     });
 
                     var worstState = getWorstState(states);
                     var c = ' marker-cluster-' + worstState;
+                    var clusterLabel = childProblem + '/' + childCount;
 
+                    if (cluster_problem_count) {
+                        clusterLabel = childProblem;
+                    }
+                    
                     return new L.DivIcon({
-                        html: '<div><span>' + childCount + '</span></div>',
+                        html: '<div><span>' + clusterLabel + '</span></div>',
                         className: 'marker-cluster' + c,
                         iconSize: new L.Point(40, 40)
                     });
@@ -524,7 +583,7 @@
 
             L.control.zoom({
                     zoomInTitle: translation['btn-zoom-in'],
-                    zoomOutTitle: translation['btn-zoom-in']
+                    zoomOutTitle: translation['btn-zoom-out']
                 }
             ).addTo(cache[id].map);
 
@@ -605,7 +664,7 @@
                         marker.addTo(cache[id].markers);
 
                         marker.on('popupclose', function (evt) {
-                            cache[id].markers.removeLayer(marker);
+                            cache[id].markers.removeLayer(evt.target);
                         });
 
                         cache[id].markers.zoomToShowLayer(marker, function () {
